/* 
  EMU_IO is a library that emulates an address/data bus to external memory
  connected to the MC9S12C32 using Port T. The library provides the following
  functions to read/write 8-bit data in an external 8-bit address space. 
*/

#include <hidef.h>
#include <mc9s12c128.h>

#ifndef __EMU_IO_H__
#define __EMU_IO_H__

/*
  emu_IO_init()
  This function initilizes Port T to act as the 8-bit data/address bus.
  Ports A and B are also initialized to provide control signals. Bit 0 of
  Port A is the Addr.H/Data.L bit and Bit 4 of Port B is the Write.H/Read.L
  bit. This function must be called before the other functions can be used.
*/
void emu_IO_init(void);

/*
  write_byte()
  input:  addr - the 8-bit address to write to
          data - the 8-bit data to write
  This function writes 8-bits of data to the specified 8-bit address.
*/
void write_byte(unsigned char addr, unsigned char data);

/*
  read_byte()
  input:  addr - the 8-bit address to read from
  output: returns the 8-bit data read from the address; undefined if an 
          address that does not exist is read.
  This function reads a byte of data from the specified 8-bit address.
*/
unsigned char read_byte(unsigned char addr);

#endif /* __EMU_IO_H__ */